pub struct GraphicsAgent { /* private fields */ }Trait Implementations
Sourceimpl Agent for GraphicsAgent
impl Agent for GraphicsAgent
Sourcetype Reach = Context<GraphicsAgent>
type Reach = Context<GraphicsAgent>
Reach capability of the agent.
Sourcetype Input = GraphicsRequest
type Input = GraphicsRequest
Incoming message type.
Sourcetype Output = GraphicsResponse
type Output = GraphicsResponse
Outgoing message type.
Sourcefn handle_input(&mut self, request: Self::Input, who: HandlerId)
fn handle_input(&mut self, request: Self::Input, who: HandlerId)
This method called on every incoming message.
Sourcefn disconnected(&mut self, id: HandlerId)
fn disconnected(&mut self, id: HandlerId)
This method called on when a new bridge destroyed.
Sourcefn name_of_resource() -> &'static str
fn name_of_resource() -> &'static str
Represents the name of loading resorce for remote workers which
have to live in a separate files.