pub struct LiveAgent { /* private fields */ }Trait Implementations
Sourceimpl Agent for LiveAgent
impl Agent for LiveAgent
Sourcetype Input = WireEnvelope<DirectId<ClientProtocol>, LiveRequest>
type Input = WireEnvelope<DirectId<ClientProtocol>, LiveRequest>
Incoming message type.
Sourcetype Output = WireEnvelope<DirectId<ClientProtocol>, LiveResponse>
type Output = WireEnvelope<DirectId<ClientProtocol>, LiveResponse>
Outgoing message type.
Sourcefn handle_input(&mut self, request: Self::Input, who: HandlerId)
fn handle_input(&mut self, request: Self::Input, who: HandlerId)
This method called on every incoming message.
Sourcefn disconnected(&mut self, _id: HandlerId)
fn disconnected(&mut self, _id: HandlerId)
This method called on when a new bridge destroyed.
Sourcefn name_of_resource() -> &'static str
fn name_of_resource() -> &'static str
Represents the name of loading resorce for remote workers which
have to live in a separate files.