pub struct WidgetRuntime<T: Widget> { /* private fields */ }Trait Implementations
Sourceimpl<T: Widget> Component for WidgetRuntime<T>
impl<T: Widget> Component for WidgetRuntime<T>
Sourcetype Message = Msg<T>
type Message = Msg<T>
Messages are used to make Components dynamic and interactive. Simple
Component’s can declare their Message type to be
(). Complex Component’s
commonly use an enum to declare multiple Message types.Sourcetype Properties = <T as Widget>::Properties
type Properties = <T as Widget>::Properties
Properties are the inputs to a Component and should not mutated within a
Component. They are passed to a Component using a JSX-style syntax. Read more
Sourcefn create(props: Self::Properties, link: ComponentLink<Self>) -> Self
fn create(props: Self::Properties, link: ComponentLink<Self>) -> Self
Components are created with their properties as well as a
ComponentLink which
can be used to send messages and create callbacks for triggering updates.Sourcefn update(&mut self, msg: Self::Message) -> ShouldRender
fn update(&mut self, msg: Self::Message) -> ShouldRender
Components handle messages in their
update method and commonly use this method
to update their state and (optionally) re-render themselves.Sourcefn change(&mut self, props: Self::Properties) -> ShouldRender
fn change(&mut self, props: Self::Properties) -> ShouldRender
When the parent of a Component is re-rendered, it will either be re-created or
receive new properties in the
change lifecycle method. Component’s can choose
to re-render if the new properties are different than the previously
received properties. Most Component’s will use props with a PartialEq
impl and will be implemented like this: Read moreSourcefn view(&self) -> Html
fn view(&self) -> Html
Components define their visual layout using a JSX-style syntax through the use of the
html! procedural macro. The full guide to using the macro can be found in Yew’s
documentation.Auto Trait Implementations
impl<T> Freeze for WidgetRuntime<T>
impl<T> !RefUnwindSafe for WidgetRuntime<T>
impl<T> !Send for WidgetRuntime<T>
impl<T> !Sync for WidgetRuntime<T>
impl<T> Unpin for WidgetRuntime<T>
impl<T> !UnwindSafe for WidgetRuntime<T>